==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Dropdown.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { DropdownPlacement_$type } from "./DropdownPlacement";
import { DropdownPositionStrategy_$type } from "./DropdownPositionStrategy";
import { DropdownScrollStrategy_$type } from "./DropdownScrollStrategy";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { DropdownItemComponentEventArgs } from "./DropdownItemComponentEventArgs";
/**
 * @hidden
 */
var Dropdown = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Dropdown, _super);
    function Dropdown() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.h = new WCNativeHelper();
        _this.p = null;
        _this.change = null;
        return _this;
    }
    Dropdown.prototype.v = function () {
        this.nativeElement.show();
    };
    Dropdown.prototype.x = function () {
        this.nativeElement.toggle();
    };
    Dropdown.prototype.showTarget = function (target_) {
        this.nativeElement.show(target_);
    };
    Dropdown.prototype.toggleTarget = function (target_) {
        this.nativeElement.toggle(target_);
    };
    Dropdown.prototype.a = function (a) {
        return (this.nativeElement.navigateTo(a));
    };
    Dropdown.prototype.b = function (a) {
        return (this.nativeElement.select(a));
    };
    Object.defineProperty(Dropdown.prototype, "i", {
        get: function () {
            return this.h;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "nativeElement", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.h.n = this.p;
        },
        enumerable: false,
        configurable: true
    });
    Dropdown.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Dropdown.prototype, "l", {
        get: function () {
            var ret_ = this.i.m("keepOpenOnSelect");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.u("keepOpenOnSelect", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "m", {
        get: function () {
            var ret_ = this.i.m("open");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.u("open", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "d", {
        get: function () {
            var ret_ = this.i.m("placement");
            ret_ = enumGetBox(DropdownPlacement_$type, EnumUtil.getEnumValue(DropdownPlacement_$type, this.i.f(DropdownPlacement_$type, ret_)));
            return EnumUtil.getEnumValue(DropdownPlacement_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DropdownPlacement_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.i.u("placement", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "e", {
        get: function () {
            var ret_ = this.i.m("positionStrategy");
            ret_ = enumGetBox(DropdownPositionStrategy_$type, EnumUtil.getEnumValue(DropdownPositionStrategy_$type, this.i.f(DropdownPositionStrategy_$type, ret_)));
            return EnumUtil.getEnumValue(DropdownPositionStrategy_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DropdownPositionStrategy_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.i.u("positionStrategy", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "f", {
        get: function () {
            var ret_ = this.i.m("scrollStrategy");
            ret_ = enumGetBox(DropdownScrollStrategy_$type, EnumUtil.getEnumValue(DropdownScrollStrategy_$type, this.i.f(DropdownScrollStrategy_$type, ret_)));
            return EnumUtil.getEnumValue(DropdownScrollStrategy_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DropdownScrollStrategy_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.i.u("scrollStrategy", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "j", {
        get: function () {
            var ret_ = this.i.m("flip");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.u("flip", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "o", {
        get: function () {
            var ret_ = this.i.m("distance");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.u("distance", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "k", {
        get: function () {
            var ret_ = this.i.m("keepOpenOnOutsideClick");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.u("keepOpenOnOutsideClick", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "n", {
        get: function () {
            var ret_ = this.i.m("sameWidth");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.u("sameWidth", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "g", {
        get: function () {
            var ret_ = this.i.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.i.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.i.u("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Dropdown.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.i.q("change", function (a) { return _this.change(_this, DropdownItemComponentEventArgs.b(a)); });
        }
        else {
            this.i.t("change");
        }
    };
    Dropdown.prototype.t = function () {
        this.nativeElement.hide();
    };
    Dropdown.prototype.s = function () {
        this.nativeElement.clearSelection();
    };
    Dropdown.$t = markType(Dropdown, 'Dropdown', BaseElement.$);
    return Dropdown;
}(BaseElement));
export { Dropdown };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/Dropdown.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { DropdownPlacement_$type } from "./DropdownPlacement";
import { DropdownPositionStrategy_$type } from "./DropdownPositionStrategy";
import { DropdownScrollStrategy_$type } from "./DropdownScrollStrategy";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { DropdownItemComponentEventArgs } from "./DropdownItemComponentEventArgs";
/**
 * @hidden
 */
var Dropdown = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Dropdown, _super);
    function Dropdown() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.h = new WCNativeHelper();
        _this.p = null;
        _this.change = null;
        return _this;
    }
    Dropdown.prototype.v = function () {
        this.nativeElement.show();
    };
    Dropdown.prototype.x = function () {
        this.nativeElement.toggle();
    };
    Dropdown.prototype.showTarget = function (target_) {
        this.nativeElement.show(target_);
    };
    Dropdown.prototype.toggleTarget = function (target_) {
        this.nativeElement.toggle(target_);
    };
    Dropdown.prototype.a = function (a) {
        return (this.nativeElement.navigateTo(a));
    };
    Dropdown.prototype.b = function (a) {
        return (this.nativeElement.select(a));
    };
    Object.defineProperty(Dropdown.prototype, "i", {
        get: function () {
            return this.h;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "nativeElement", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.h.o = this.p;
        },
        enumerable: false,
        configurable: true
    });
    Dropdown.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Dropdown.prototype, "l", {
        get: function () {
            var ret_ = this.i.n("keepOpenOnSelect");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.v("keepOpenOnSelect", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "m", {
        get: function () {
            var ret_ = this.i.n("open");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.v("open", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "d", {
        get: function () {
            var ret_ = this.i.n("placement");
            ret_ = enumGetBox(DropdownPlacement_$type, EnumUtil.getEnumValue(DropdownPlacement_$type, this.i.f(DropdownPlacement_$type, ret_)));
            return EnumUtil.getEnumValue(DropdownPlacement_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DropdownPlacement_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("placement", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "e", {
        get: function () {
            var ret_ = this.i.n("positionStrategy");
            ret_ = enumGetBox(DropdownPositionStrategy_$type, EnumUtil.getEnumValue(DropdownPositionStrategy_$type, this.i.f(DropdownPositionStrategy_$type, ret_)));
            return EnumUtil.getEnumValue(DropdownPositionStrategy_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DropdownPositionStrategy_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("positionStrategy", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "f", {
        get: function () {
            var ret_ = this.i.n("scrollStrategy");
            ret_ = enumGetBox(DropdownScrollStrategy_$type, EnumUtil.getEnumValue(DropdownScrollStrategy_$type, this.i.f(DropdownScrollStrategy_$type, ret_)));
            return EnumUtil.getEnumValue(DropdownScrollStrategy_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(DropdownScrollStrategy_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("scrollStrategy", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "j", {
        get: function () {
            var ret_ = this.i.n("flip");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.v("flip", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "o", {
        get: function () {
            var ret_ = this.i.n("distance");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.v("distance", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "k", {
        get: function () {
            var ret_ = this.i.n("keepOpenOnOutsideClick");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.v("keepOpenOnOutsideClick", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "n", {
        get: function () {
            var ret_ = this.i.n("sameWidth");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.i.v("sameWidth", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Dropdown.prototype, "g", {
        get: function () {
            var ret_ = this.i.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.i.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.i.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    Dropdown.prototype.changeChanged = function () {
        var _this = this;
        if (this.change != null) {
            this.i.r("change", function (a) { return _this.change(_this, DropdownItemComponentEventArgs.b(a)); });
        }
        else {
            this.i.u("change");
        }
    };
    Dropdown.prototype.t = function () {
        this.nativeElement.hide();
    };
    Dropdown.prototype.s = function () {
        this.nativeElement.clearSelection();
    };
    Dropdown.$t = markType(Dropdown, 'Dropdown', BaseElement.$);
    return Dropdown;
}(BaseElement));
export { Dropdown };
